leaftools.yield_groups_of_mixed_notes_and_chords_in_sequence
============================================================

.. autofunction:: abjad.tools.leaftools.yield_groups_of_mixed_notes_and_chords_in_sequence.yield_groups_of_mixed_notes_and_chords_in_sequence
